summaryrefslogtreecommitdiff
path: root/root-topology/mktopology.cpp
diff options
context:
space:
mode:
authorKees Bos <k.bos@capitar.com>2015-05-06 12:05:20 +0200
committerKees Bos <k.bos@capitar.com>2015-05-06 12:05:20 +0200
commita425bbc67301bf486fe5b0aba8adb59ae791403e (patch)
tree460b6c5a5c2ed852903fac2a9703c6f06534f79f /root-topology/mktopology.cpp
parent845955dea53035e8472059ff03feca9f47c0d5fa (diff)
downloadinfinitytier-a425bbc67301bf486fe5b0aba8adb59ae791403e.tar.gz
infinitytier-a425bbc67301bf486fe5b0aba8adb59ae791403e.zip
Renamed supernode to rootserver
Diffstat (limited to 'root-topology/mktopology.cpp')
-rw-r--r--root-topology/mktopology.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/root-topology/mktopology.cpp b/root-topology/mktopology.cpp
index 00ada7b7..f0ad5b55 100644
--- a/root-topology/mktopology.cpp
+++ b/root-topology/mktopology.cpp
@@ -30,21 +30,21 @@ int main(int argc,char **argv)
if (OSUtils::readFile("template.dict",buf))
topology.fromString(buf);
- // Read all entries in supernodes/ that correspond to supernode entry dictionaries
- // and add them to topology under supernodes/ subkey.
- Dictionary supernodes;
- std::vector<std::string> supernodeDictionaries(OSUtils::listDirectory("supernodes"));
- for(std::vector<std::string>::const_iterator sn(supernodeDictionaries.begin());sn!=supernodeDictionaries.end();++sn) {
+ // Read all entries in rootservers/ that correspond to rootserver entry dictionaries
+ // and add them to topology under rootservers/ subkey.
+ Dictionary rootservers;
+ std::vector<std::string> rootserverDictionaries(OSUtils::listDirectory("rootservers"));
+ for(std::vector<std::string>::const_iterator sn(rootserverDictionaries.begin());sn!=rootserverDictionaries.end();++sn) {
if (sn->length() == 10) {
buf.clear();
- if (!OSUtils::readFile((std::string("supernodes/")+(*sn)).c_str(),buf)) {
- std::cerr << "Cannot read supernodes/" << *sn << std::endl;
+ if (!OSUtils::readFile((std::string("rootservers/")+(*sn)).c_str(),buf)) {
+ std::cerr << "Cannot read rootservers/" << *sn << std::endl;
return 1;
}
- supernodes[*sn] = buf;
+ rootservers[*sn] = buf;
}
}
- topology["supernodes"] = supernodes.toString();
+ topology["rootservers"] = rootservers.toString();
if ((topologyAuthority)&&(topologyAuthority.hasPrivate())) {
// Sign topology with root-topology-authority.secret